@@ -2,6 +2,7 @@ from .base import BaseDifferentiation
 from .finite_difference import FiniteDifference
 from .sindy_derivative import SINDyDerivative
 from .smoothed_finite_difference import SmoothedFiniteDifference
+from .spectral_derivative import SpectralDerivative
 
 
 __all__ = [
@@ -9,4 +10,5 @@ __all__ = [
     "FiniteDifference",
     "SINDyDerivative",
     "SmoothedFiniteDifference",
+    "SpectralDerivative",
 ]
