@@ -52,7 +52,7 @@ class SINDyDerivative(BaseEstimator):
             # Simple optimization to gain speed (inspect is slow)
             return self
         else:
-            self.kwargs.update(params)
+            self.kwargs.update(params["kwargs"])
 
         return self
 
